==> moodle-1.5-mysql.tgz: moodle/lang/sk/install.php <==
<?PHP // $Id$ 
      // install.php - created with Moodle 1.6 development (2005052400)


$string['admindirerror'] = 'Adresr pre sprvu (admin) nie je uren sprvne';
$string['admindirname'] = 'Adresr pre sprvu (admin)';
$string['admindirsetting'] = 'Niektor poskytovatelia web priestoru pouvaj adresr /admin pre prstup ku kontrolnmu panelu, prpadne ku podobnm funkcim. To bohuia nie je v slade so tandardnm umiestnenm adresru pre sprvu v Moodle. Tento konflikt je mon vyriei premenovanm adresru pre sprvu vo Vaej intalcii. Vlote sem nov nzov, napr.<br /><br />
<b>moodleadmin</b><br /><br />
Tm se opravia odkazy na sprvu Moodle.';
$string['caution'] = 'Varovanie';
$string['chooselanguage'] = 'Vyberte jazyk';
$string['compatibilitysettings'] = 'Kontrola nastaven vho PHP...';
$string['configfilenotwritten'] = 'Intalan skript nebol schopn automaticky vytvori  config.php sbor, obsahujci Vae zvolen nastavenia, pravdepodobne preto, e adresr Moodle nie je zapisovaten. Mete rune skoprova nasledovn kd do sboru s nzvom config.php v rmci  koreovho adresra Moodle.';
$string['configfilewritten'] = 'sbor config.php bol spene vytvoren';
$string['configurationcomplete'] = 'Konfigurcia ukonen';
$string['database'] = 'Databza';
$string['databasesettings'] = 'Teraz potrebujete nastavi databzu, kde bude uchovvan vina dajov Moodle. Tto databza vak mus by predtm vytvoren a tie mus by vytvoren uvatesk meno a prstupov heslo.<br /><br /><br />
<b>Typ:</b> mysql alebo postgres7<br />
<b>Host:</b> napr. localhost alebo db.isp.com<br />
<b>Meno:</b> meno databzy, napr. moodle<br />
<b>Uvate:</b> uvatesk meno Vaej databzy<br />
<b>Heslo:</b> heslo Vaej databzy<br />
<b>Predpona tabuliek:</b> nepovinn predpona pre vetky men tabuliek';
$string['dataroot'] = 'Adresr pre daje';
$string['datarooterror'] = '\'Adresr pre daje\', ktor ste zadali, neme by njden alebo vytvoren. Upravte bu cestu alebo vytvorte ten adresr rune.';
$string['dbconnectionerror'] = 'Nemohli sme sa pripoji k vami zadanej databze. Prosm skontrolujte nastavenia Vaej databzy.';
$string['dbcreationerror'] = 'Chyba pri vytvran databzy. Nebolo mon vytvori databzu so zadanm menom a jej nastaveniami';
$string['dbhost'] = 'Hosovsk server';
$string['dbpass'] = 'Heslo';
$string['dbprefix'] = 'Predpona tabuliek';
$string['dbtype'] = 'Typ';
$string['directorysettings'] = '<p>Prosm, potvrte umiestnenie intalcie Moodle.</p>

<p><b>Web adresa:</b> pecifikujte cel web adresu, kde bude Moodle umiestnen. Ak sa na tto adresu pristupuje z viacerch url adries, potom vyberte t, ktor bud pouva Vai tudenti. Na konci nepouvajte lomtko.</p>

<p><b>Adresr Moodle:</b> pecifikujte cel cestu k adresru a tejto intalcii. Ubezpete sa, e ste korektne pouili vek a mal psmen.</p>

<p><b>Adresr pre daje:</b> Potrebujete miesto, kde Moodle bude uklada prenan sbory. Tento adresr by mal by uvateovi webovho servera prstupn aj na tanie, aj na ZAPISOVANIE (zvyajne \'nobody\' alebo \'apache\'), ale nemalo by sa da k nemu pristupova priamo z webu.</p>';
$string['dirroot'] = 'Adresr Moodle';
$string['dirrooterror'] = 'Nastavenia v \'Adresri Moodle\' s nesprvne - nememe tu njs intalciu Moodle. Hodnota dole bola vynulovan.';
$string['download'] = 'Stiahnu';
$string['fail'] = 'Nespen';
$string['fileuploads'] = 'prenesen sbory';
$string['fileuploadserror'] = 'Toto by malo by zapnut';
$string['fileuploadshelp'] = '<p>Zd sa, e na Vaom serveri nie je aktivovan prenos sborov.</p>

<p>Moodle me by aj napriek tomu naintalovan, ale bez tejto monosti, nebudete schopn prenies sbory kurzu, alebo obrzky v novch uvateskch profiloch.</p>

<p>Na aktivovanie prenosu sborov, Vy (alebo V systmov administrtor) budete musie upravi main php.ini sbor v systme a zmeni nastavenie pre <b>file_uploads</b> na \'1\'.</p>';
$string['gdversion'] = 'Verzia kninice GD';
$string['gdversionerror'] = 'Kninica GD by mala existova na spracovvanie a vytvranie obrzkov';
$string['gdversionhelp'] = '<p>Na Vaom serveri zrejme nie je naintalovan GD kninica.</p>

<p>GD je kninica, ktor si vyaduje PHP, aby mohlo Moodle povoli spracovva obrzky (napr. ikony v uvateskch profiloch) a vytvra nov obrzky (napr. grafy z prihlsen). Moodle bude stle pracova bez GD - tieto monosti bud dostupn len Vm.</p>

<p>Ke chcete prida GD do PHP pod Unixom, vytvorte PHP pouitm --with-gd parameter.</p>

<p>Pod Windows mete upravi php.ini a odkomentova riadok obsahujci libgd.dll.</p>';
$string['installation'] = 'Intalcia';
$string['magicquotesruntime'] = 'Magic Quotes Run Time';
$string['magicquotesruntimeerror'] = 'Toto by malo by vypnut';
$string['magicquotesruntimehelp'] = '<p>Magic quotes runtime by malo by vypnut, aby Moodle fungoval tak, ako m.</p>

<p>Zvyajne je voba tandardne vypnut ... pozri nastavenia <b>magic_quotes_runtime</b> vo Vaom php.ini sbore.</p>

<p>Ak nemte prstup k sboru php.ini, mali by ste nasledovn riadok do sboru s nzvom .htaccess v rmci adresra Moodle: 
<blockquote>php_value magic_quotes_runtime Off</blockquote>
</p> ';
$string['memorylimit'] = 'Limit pamte';
$string['memorylimiterror'] = 'PHP limit pamte je nastaven na minimum...S tmto mete ma neskr problmy.';
$string['memorylimithelp'] = '<p>PHP limit pamte pre V server je momentlne nastaven na $a.</p>

<p>Toto me neskr spsobi problmy v Moodle, najm ak mte vea modulov a/alebo vea uvateov.</p>

<p>Odporame Vm, aby ste nastavili PHP s vym limitom pamte, ak je to mon, napr. 16M. Na to existuje vea spsobov, ktor mete vyska:</p>
<ol>
<li>Ak je to mon, znovu vytvorte PHP s <i>--enable-memory-limit</i>. Toto umon Moodle samonastavenie limitu pamte.</li>
<li>Ak mte prstup k Vmu php.ini sboru, mete zmeni <b>memory_limit</b> nastavenie, napr. na 16M. Ak nemte prstup k sboru, mete sa na to spta Vho administrtora.</li>
Na niektorch PHP serveroch, si mete vytvori sbor .htaccess v Adresri Moodle, ktor bude obsahova tento riadok: <p><blockquote>php_value memory_limit 16M</blockquote></p>
<p>Avak, na niektorch serveroch bude toto brni <b>vetkm</b> PHP strnkam v prci (budete vidie chyby, ke sa pozriete na strnky), take budete musie odstrni sbor .htaccess.</p></li>
</ol> 	';
$string['mysqlextensionisnotpresentinphp'] = 'PHP nebolo sprvne nakonfigurovan s MySQL rozrenm a tak neme komunikova s MySQL. Prosm, skontrolujte si V php.ini sbor alebo znovu vytvorte PHP.';
$string['pass'] = 'Prejs';
$string['phpversion'] = 'Verzia PHP';
$string['phpversionerror'] = 'Verzia PHP mus by aspo  4.1.0';
$string['phpversionhelp'] = '<p>Moodle si vyaduje verziu PHP aspo  4.1.0.</p>
<p>Vy mte momentlne naintalovan tto verziu $a</p>
<p>Muste obnovi PHP alebo presun na hostitesk pota s novou verziou PHP!</p>';
$string['safemode'] = 'Bezpen md';
$string['safemodeerror'] = 'Moodle me ma problmy, ak je zapnut bezpen md';
$string['safemodehelp'] = '<p>Moodle me ma viacero problmov, ak je zapnut bezpen md, pravdepodobne nedovol vytvra nov sbory.</p>

<p>Bezpen md je zvyajne povolen verejnmi poskytovatemi webovho priestoru, take by ste si mali njs novho poskytovatea webovho priestoru pre strnku Moodle.</p>';
$string['sessionautostart'] = 'Autotart sekcie';
$string['sessionautostarterror'] = 'Toto by malo by vypnut';
$string['sessionautostarthelp'] = '<p>Moodle vyaduje podporu sekcie a nebude bez nej fungova.</p>';
$string['wwwroot'] = 'Web adresa';
$string['wwwrooterror'] = 'Tto web adresa pravdepodobne nie je platn - tto intalcia Moodle tu pravdepodobne nie je.';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/sk/install.php <==
<?PHP // $Id$ 
      // install.php - created with Moodle 1.6 development (2005052400)


$string['admindirerror'] = 'Adresr pre sprvu (admin) nie je uren sprvne';
$string['admindirname'] = 'Adresr pre sprvu (admin)';
$string['admindirsetting'] = 'Niektor poskytovatelia web priestoru pouvaj adresr /admin pre prstup ku kontrolnmu panelu, prpadne ku podobnm funkcim. To bohuia nie je v slade so tandardnm umiestnenm adresru pre sprvu v Moodle. Tento konflikt je mon vyriei premenovanm adresru pre sprvu vo Vaej intalcii. Vlote sem nov nzov, napr.<br /><br />
<b>moodleadmin</b><br /><br />
Tm se opravia odkazy na sprvu Moodle.';
$string['caution'] = 'Varovanie';
$string['chooselanguage'] = 'Vyberte jazyk';
$string['compatibilitysettings'] = 'Kontrola nastaven vho PHP...';
$string['configfilenotwritten'] = 'Intalan skript nebol schopn automaticky vytvori  config.php sbor, obsahujci Vae zvolen nastavenia, pravdepodobne preto, e adresr Moodle nie je zapisovaten. Mete rune skoprova nasledovn kd do sboru s nzvom config.php v rmci  koreovho adresra Moodle.';
$string['configfilewritten'] = 'sbor config.php bol spene vytvoren';
$string['configurationcomplete'] = 'Konfigurcia ukonen';
$string['database'] = 'Databza';
$string['databasesettings'] = 'Teraz potrebujete nastavi databzu, kde bude uchovvan vina dajov Moodle. Tto databza vak mus by predtm vytvoren a tie mus by vytvoren pouvatesk meno a prstupov heslo.<br /><br /><br />
<b>Typ:</b> mysql alebo postgres7<br />
<b>Host:</b> napr. localhost alebo db.isp.com<br />
<b>Meno:</b> meno databzy, napr. moodle<br />
<b>Pouvate:</b> pouvatesk meno Vaej databzy<br />
<b>Heslo:</b> heslo Vaej databzy<br />
<b>Predpona tabuliek:</b> nepovinn predpona pre vetky men tabuliek';
$string['dataroot'] = 'Adresr pre daje';
$string['datarooterror'] = '\'Adresr pre daje\', ktor ste zadali, neme by njden alebo vytvoren. Upravte bu cestu alebo vytvorte ten adresr rune.';
$string['dbconnectionerror'] = 'Nemohli sme sa pripoji k vami zadanej databze. Prosm skontrolujte nastavenia Vaej databzy.';
$string['dbcreationerror'] = 'Chyba pri vytvran databzy. Nebolo mon vytvori databzu so zadanm menom a jej nastaveniami';
$string['dbhost'] = 'Hosovsk server';
$string['dbpass'] = 'Heslo';
$string['dbprefix'] = 'Predpona tabuliek';
$string['dbtype'] = 'Typ';
$string['directorysettings'] = '<p>Prosm, potvrte umiestnenie intalcie Moodle.</p>

<p><b>Web adresa:</b> pecifikujte cel web adresu, kde bude Moodle umiestnen. Ak sa na tto adresu pristupuje z viacerch url adries, potom vyberte t, ktor bud pouva Vai tudenti. Na konci nepouvajte lomtko.</p>

<p><b>Adresr Moodle:</b> pecifikujte cel cestu k adresru a tejto intalcii. Ubezpete sa, e ste korektne pouili vek a mal psmen.</p>

<p><b>Adresr pre daje:</b> Potrebujete miesto, kde Moodle bude uklada prenan sbory. Tento adresr by mal by pouvateovi webovho servera prstupn aj na tanie, aj na ZAPISOVANIE (zvyajne \'nobody\' alebo \'apache\'), ale nemalo by sa da k nemu pristupova priamo z webu.</p>';
$string['dirroot'] = 'Adresr Moodle';
$string['dirrooterror'] = 'Nastavenia v \'Adresri Moodle\' s nesprvne - nememe tu njs intalciu Moodle. Hodnota dole bola vynulovan.';
$string['download'] = 'Stiahnu';
$string['fail'] = 'Nespen';
$string['fileuploads'] = 'prenesen sbory';
$string['fileuploadserror'] = 'Toto by malo by zapnut';
$string['fileuploadshelp'] = '<p>Zd sa, e na Vaom serveri nie je aktivovan prenos sborov.</p>

<p>Moodle me by aj napriek tomu naintalovan, ale bez tejto monosti, nebudete schopn prenies sbory kurzu, alebo obrzky v novch pouvateskch profiloch.</p>

<p>Na aktivovanie prenosu sborov, Vy (alebo V systmov administrtor) budete musie upravi main php.ini sbor v systme a zmeni nastavenie pre <b>file_uploads</b> na \'1\'.</p>';
$string['gdversion'] = 'Verzia kninice GD';
$string['gdversionerror'] = 'Kninica GD by mala existova na spracovvanie a vytvranie obrzkov';
$string['gdversionhelp'] = '<p>Na Vaom serveri zrejme nie je naintalovan GD kninica.</p>

<p>GD je kninica, ktor si vyaduje PHP, aby mohlo Moodle povoli spracovva obrzky (napr. ikony v pouvateskch profiloch) a vytvra nov obrzky (napr. grafy z prihlsen). Moodle bude stle pracova bez GD - tieto monosti bud dostupn len Vm.</p>

<p>Ke chcete prida GD do PHP pod Unixom, vytvorte PHP pouitm --with-gd parameter.</p>

<p>Pod Windows mete upravi php.ini a odkomentova riadok obsahujci libgd.dll.</p>';
$string['installation'] = 'Intalcia';
$string['magicquotesruntime'] = 'Magic Quotes Run Time';
$string['magicquotesruntimeerror'] = 'Toto by malo by vypnut';
$string['magicquotesruntimehelp'] = '<p>Magic quotes runtime by malo by vypnut, aby Moodle fungoval tak, ako m.</p>

<p>Zvyajne je voba tandardne vypnut ... pozri nastavenia <b>magic_quotes_runtime</b> vo Vaom php.ini sbore.</p>

<p>Ak nemte prstup k sboru php.ini, mali by ste nasledovn riadok do sboru s nzvom .htaccess v rmci adresra Moodle: 
<blockquote>php_value magic_quotes_runtime Off</blockquote>
</p> ';
$string['memorylimit'] = 'Limit pamte';
$string['memorylimiterror'] = 'PHP limit pamte je nastaven na minimum...S tmto mete ma neskr problmy.';
$string['memorylimithelp'] = '<p>PHP limit pamte pre V server je momentlne nastaven na $a.</p>

<p>Toto me neskr spsobi problmy v Moodle, najm ak mte vea modulov a/alebo vea pouvateov.</p>

<p>Odporame Vm, aby ste nastavili PHP s vym limitom pamte, ak je to mon, napr. 16M. Na to existuje vea spsobov, ktor mete vyska:</p>
<ol>
<li>Ak je to mon, znovu vytvorte PHP s <i>--enable-memory-limit</i>. Toto umon Moodle samonastavenie limitu pamte.</li>
<li>Ak mte prstup k Vmu php.ini sboru, mete zmeni <b>memory_limit</b> nastavenie, napr. na 16M. Ak nemte prstup k sboru, mete sa na to spta Vho administrtora.</li>
Na niektorch PHP serveroch, si mete vytvori sbor .htaccess v Adresri Moodle, ktor bude obsahova tento riadok: <p><blockquote>php_value memory_limit 16M</blockquote></p>
<p>Avak, na niektorch serveroch bude toto brni <b>vetkm</b> PHP strnkam v prci (budete vidie chyby, ke sa pozriete na strnky), take budete musie odstrni sbor .htaccess.</p></li>
</ol> 	';
$string['mysqlextensionisnotpresentinphp'] = 'PHP nebolo sprvne nakonfigurovan s MySQL rozrenm a tak neme komunikova s MySQL. Prosm, skontrolujte si V php.ini sbor alebo znovu vytvorte PHP.';
$string['pass'] = 'Prejs';
$string['phpversion'] = 'Verzia PHP';
$string['phpversionerror'] = 'Verzia PHP mus by aspo  4.1.0';
$string['phpversionhelp'] = '<p>Moodle si vyaduje verziu PHP aspo  4.1.0.</p>
<p>Vy mte momentlne naintalovan tto verziu $a</p>
<p>Muste obnovi PHP alebo presun na hostitesk pota s novou verziou PHP!</p>';
$string['safemode'] = 'Bezpen md';
$string['safemodeerror'] = 'Moodle me ma problmy, ak je zapnut bezpen md';
$string['safemodehelp'] = '<p>Moodle me ma viacero problmov, ak je zapnut bezpen md, pravdepodobne nedovol vytvra nov sbory.</p>

<p>Bezpen md je zvyajne povolen verejnmi poskytovatemi webovho priestoru, take by ste si mali njs novho poskytovatea webovho priestoru pre strnku Moodle.</p>';
$string['sessionautostart'] = 'Autotart sekcie';
$string['sessionautostarterror'] = 'Toto by malo by vypnut';
$string['sessionautostarthelp'] = '<p>Moodle vyaduje podporu sekcie a nebude bez nej fungova.</p>';
$string['wwwroot'] = 'Web adresa';
$string['wwwrooterror'] = 'Tto web adresa pravdepodobne nie je platn - tto intalcia Moodle tu pravdepodobne nie je.';

?>
